plugins package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   plugins.core
   plugins.debate

Module contents
---------------

.. automodule:: plugins
   :members:
   :undoc-members:
   :show-inheritance:
